==> batchcomputecli-0.0.19.tar.gz: batchcomputecli-0.0.19/src/batchcomputecli/services/util.py <==
import terminal
import datetime
import time

from ..const import STRING

JOB_COLS = ['JobId', 'JobName', 'State', 'Progress', 'Elapsed','StartTime', 'EndTime']

JOB_KEYS = ['NumFinishedInstance', 'NumWaitingInstance', 'NumRunningTask', 'JobName', 'Priority', 'State', 'OwnerId',
            'NumFailedTask', 'EndTime', 'Description', 'NumRunningInstance', 'NumTotalInstance', 'JobId',
            'NumStoppedTask',
            'NumTotalTask', 'NumFinishedTask', 'NumStoppedInstance', 'TotalTime', 'NumWaitingTask', 'StartTime',
            'NumFailedInstance', 'CreateTime','Elapsed']

TASK_KEYS = ['TaskName', 'State', 'StartTime', 'EndTime', 'InstanceList','Elapsed']

TASK_COLS = ['TaskName', 'State', 'Progress', 'Elapsed', 'StartTime', 'EndTime']

TASK_DESC_COLS = ["InstanceCount", "PackageUri", "ProgramName", "OssMappingLock", "ResourceDescription",
                  "OssMappingLocale", "StdoutRedirectPath", "ImageId",
                  "EnvironmentVariables", "Timeout", "ProgramType", "ProgramArguments", "StderrRedirectPath",
                  "OssMapping"]
INSTANCE_COLS = ['InstanceId', 'State', 'StartTime', 'EndTime']


def filter_list(arr, filters):
    '''
    fitlers:
       1. {State:['Running','Waiting']}
       2. {NumRunningInstance: {'>': 1}}
       3. {JobName: {'like':'jobName1'}}
    '''
    t = []

    for k in filters:
        if isinstance(filters[k], STRING):
            t = [item for item in arr if filters[k] == item[k]]
        if isinstance(filters[k], (list,tuple)):
            t = [item for item in arr if (item[k] != None and (item[k] in filters[k]))]
        if isinstance(filters[k], dict):
            like = filters[k].get('like')
            gt = filters[k].get('>')
            lt = filters[k].get('<')

            if like != None:
                like = like.lower()
                t = [item for item in arr if like in item[k].lower()]

            elif (gt != None or lt != None):
                t = [item for item in arr
                     if (gt == None or gt != None and item[k] > gt) or (lt == None or lt != None and item[k] < lt)]
            else:
                t = arr
    return t;


def order_by(arr, cols, desc=None):
    # def __cmp(a, b):
    #     for c in cols:
    #         if a.get(c) == b.get(c):
    #             continue
    #         elif a.get(c) > b.get(c):
    #             return -1 if desc else 1
    #         else:
    #             return 1 if desc else -1
    #     return 0

    arr.sort(key=lambda x:[x[c] for c in cols], reverse=desc)
    return arr


def to_dict(item, keys):
    n = {}
    for k in keys:
        n[k] = item.get(k)
    return n

def state_count_flat(obj):
    arr = ['Waiting','Running','Finished','Failed','Stopped']
    t = []
    for k in arr:
       t.append('%s:%s' % (get_color_state(k), obj[k]))
    return '  '.join(t)

def calc_task_progress(arr):
    t = []
    for item in arr:
        n = to_dict(item, TASK_KEYS)

        counts = {
            'Stopped' : 0,
            'Finished' : 0,
            'Running' : 0,
            'Waiting' : 0,
            'Failed' : 0
        }

        total = len(n.get('InstanceList'))

        for k in n.get('InstanceList'):
            counts[k.State] += 1

        n['StoppedTask'] = counts.get('Stopped')
        n['Percent'] = int((counts.get('Failed')+counts.get('Finished')) * 100 / total)
        has = int(n['Percent'] / 5)
        hasnt = 20 - has
        n['ProgressTxt'] = '%s%s%d/%d' % ('=' * has, '-' * hasnt, counts.get('Failed')+counts.get('Finished'), total)

        n['Progress'] = '%s%s%d/%d' % (
            get_color_state(n['State'], '=' * has), '-' * hasnt, counts.get('Failed')+counts.get('Finished'), total)

        n['StateCount'] = counts
        t.append(n)

    return t


def calc_job_progress(arr):
    t = []
    for item in arr:
        n = to_dict(item, JOB_KEYS)

        n['StoppedTask'] = n.get('NumStoppedTask')

        finished = n.get('NumFailedTask') + n.get('NumFinishedTask')
        n['Percent'] = int(finished * 100 / n.get('NumTotalTask'))

        has = int(n['Percent'] / 5)
        hasnt = 20 - has
        n['ProgressTxt'] = '%s%s%d/%d' % ('=' * has, '-' * hasnt, finished, n.get('NumTotalTask'))

        n['Progress'] = '%s%s%d/%d' % (
            get_color_state(n['State'], '=' * has), '-' * hasnt, finished, n.get('NumTotalTask'))
        t.append(n)

    return t


def get_color_state(state, s=None):
    s = state if s == None else s
    return {
       'Waiting': terminal.gray(s),
       'Running': terminal.blue(s),
       'Failed':  terminal.red(s),
       'Finished':  terminal.green(s),
       'Stopped':  terminal.yellow(s),
    }.get(state) or terminal.white(s)


def format_date_fields(arr, fields, keys):
    t = []
    for item in arr:
        n = to_dict(item, keys)
        if item.get('StartTime') != None and item.get('EndTime') != None:
            v = time.time() if item.get('EndTime')==0 else item.get('EndTime')
            n['Elapsed'] = format_elapsed(v - item.get('StartTime'))

        for k in fields:
            if n.get(k):
                n[k] = format_sec_date(n[k])
        t.append(n)
    return t

def format_elapsed(sec):
    t=[]
    if sec > 24*3600:
        d = int(sec/(24*3600))
        sec = sec - d*24*3600
        t.append('%sd'%d)
    if sec > 3600:
        h = int(sec/3600)
        sec = sec - h*3600
        t.append('%sh'%h)
    if sec > 60:
        m = int(sec/60)
        sec = sec - m*60
        t.append('%sm'%m)
    if sec > 0:
        t.append('%ss'%sec)
    return ''.join(t)


def format_sec_date(sec):
    v = datetime.datetime.utcfromtimestamp(sec)
    return v.strftime("%Y-%m-%d %H:%M:%S")

==> batchcomputecli-0.0.20.tar.gz: batchcomputecli-0.0.20/src/batchcomputecli/services/util.py <==
import terminal
import datetime
import time

from ..const import STRING

JOB_COLS = ['JobId', 'JobName', 'State', 'Progress', 'Elapsed','StartTime', 'EndTime']

JOB_KEYS = ['NumFinishedInstance', 'NumWaitingInstance', 'NumRunningTask', 'JobName', 'Priority', 'State', 'OwnerId',
            'NumFailedTask', 'EndTime', 'Description', 'NumRunningInstance', 'NumTotalInstance', 'JobId',
            'NumStoppedTask',
            'NumTotalTask', 'NumFinishedTask', 'NumStoppedInstance', 'TotalTime', 'NumWaitingTask', 'StartTime',
            'NumFailedInstance', 'CreateTime','Elapsed']

TASK_KEYS = ['TaskName', 'State', 'StartTime', 'EndTime', 'InstanceList','Elapsed']

TASK_COLS = ['TaskName', 'State', 'Progress', 'Elapsed', 'StartTime', 'EndTime']

TASK_DESC_COLS = ["InstanceCount", "PackageUri", "ProgramName", "OssMappingLock", "ResourceDescription",
                  "OssMappingLocale", "StdoutRedirectPath", "ImageId",
                  "EnvironmentVariables", "Timeout", "ProgramType", "ProgramArguments", "StderrRedirectPath",
                  "OssMapping"]
INSTANCE_COLS = ['InstanceId', 'State', 'StartTime', 'EndTime']


def filter_list(arr, filters):
    '''
    fitlers:
       1. {State:['Running','Waiting']}
       2. {NumRunningInstance: {'>': 1}}
       3. {JobName: {'like':'jobName1'}}
    '''
    t = []

    for k in filters:
        if isinstance(filters[k], STRING):
            t = [item for item in arr if filters[k] == item[k]]
        if isinstance(filters[k], (list,tuple)):
            t = [item for item in arr if (item[k] != None and (item[k] in filters[k]))]
        if isinstance(filters[k], dict):
            like = filters[k].get('like')
            gt = filters[k].get('>')
            lt = filters[k].get('<')

            if like != None:
                like = like.lower()
                t = [item for item in arr if like in item[k].lower()]

            elif (gt != None or lt != None):
                t = [item for item in arr
                     if (gt == None or gt != None and item[k] > gt) or (lt == None or lt != None and item[k] < lt)]
            else:
                t = arr
    return t;


def order_by(arr, cols, desc=None):
    # def __cmp(a, b):
    #     for c in cols:
    #         if a.get(c) == b.get(c):
    #             continue
    #         elif a.get(c) > b.get(c):
    #             return -1 if desc else 1
    #         else:
    #             return 1 if desc else -1
    #     return 0

    arr.sort(key=lambda x:[x[c] for c in cols], reverse=desc)
    return arr


def to_dict(item, keys):
    n = {}
    for k in keys:
        n[k] = item.get(k)
    return n

def state_count_flat(obj):
    arr = ['Waiting','Running','Finished','Failed','Stopped']
    t = []
    for k in arr:
       t.append('%s:%s' % (get_color_state(k), obj[k]))
    return '  '.join(t)

def calc_task_progress(arr):
    t = []
    for item in arr:
        n = to_dict(item, TASK_KEYS)

        counts = {
            'Stopped' : 0,
            'Finished' : 0,
            'Running' : 0,
            'Waiting' : 0,
            'Failed' : 0
        }

        total = len(n.get('InstanceList'))

        for k in n.get('InstanceList'):
            counts[k.State] += 1

        n['StoppedTask'] = counts.get('Stopped')
        n['Percent'] = int((counts.get('Failed')+counts.get('Finished')) * 100 / total)
        has = int(n['Percent'] / 5)
        hasnt = 20 - has
        n['ProgressTxt'] = '%s%s%d/%d' % ('=' * has, '-' * hasnt, counts.get('Failed')+counts.get('Finished'), total)

        n['Progress'] = '%s%s%d/%d' % (
            get_color_state(n['State'], '=' * has), '-' * hasnt, counts.get('Failed')+counts.get('Finished'), total)

        n['StateCount'] = counts
        t.append(n)

    return t


def calc_job_progress(arr):
    t = []
    for item in arr:
        n = to_dict(item, JOB_KEYS)

        n['StoppedTask'] = n.get('NumStoppedTask')

        finished = n.get('NumFailedTask') + n.get('NumFinishedTask')
        n['Percent'] = int(finished * 100 / n.get('NumTotalTask'))

        has = int(n['Percent'] / 5)
        hasnt = 20 - has
        n['ProgressTxt'] = '%s%s%d/%d' % ('=' * has, '-' * hasnt, finished, n.get('NumTotalTask'))

        n['Progress'] = '%s%s%d/%d' % (
            get_color_state(n['State'], '=' * has), '-' * hasnt, finished, n.get('NumTotalTask'))
        t.append(n)

    return t


def get_color_state(state, s=None):
    s = state if s == None else s
    return {
       'Waiting': terminal.white(s),
       'Running': terminal.blue(s),
       'Failed':  terminal.red(s),
       'Finished':  terminal.green(s),
       'Stopped':  terminal.yellow(s),
    }.get(state) or terminal.white(s)


def format_date_fields(arr, fields, keys):
    t = []
    for item in arr:
        n = to_dict(item, keys)
        if item.get('StartTime') != None and item.get('EndTime') != None:
            v = time.time() if item.get('EndTime')==0 else item.get('EndTime')
            n['Elapsed'] = format_elapsed(v - item.get('StartTime'))

        for k in fields:
            if n.get(k):
                n[k] = format_sec_date(n[k])
        t.append(n)
    return t

def format_elapsed(sec):
    t=[]
    if sec > 24*3600:
        d = int(sec/(24*3600))
        sec = sec - d*24*3600
        t.append('%sd'%d)
    if sec > 3600:
        h = int(sec/3600)
        sec = sec - h*3600
        t.append('%sh'%h)
    if sec > 60:
        m = int(sec/60)
        sec = sec - m*60
        t.append('%sm'%m)
    if sec > 0:
        t.append('%ss'% int(sec))
    return ''.join(t)


def format_sec_date(sec):
    v = datetime.datetime.utcfromtimestamp(sec)
    return v.strftime("%Y-%m-%d %H:%M:%S")
